==> jc-1.4.0.tar.gz: gnu/java/security/provider/GnuDSAPrivateKey.h <==
// public class gnu.java.security.provider.GnuDSAPrivateKey

// class file dependencies
// @dep_class 9f2cf38c416cedcf gnu_java_security_provider_GnuDSAPrivateKey
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_provider_GnuDSAPrivateKey_H_
#define _JC_gnu_java_security_provider_GnuDSAPrivateKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;
struct _jc_java_security_interfaces_DSAParams$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$sub_refs	_jc_gnu_java_security_provider_GnuDSAPrivateKey$sub_refs;
typedef struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$sub_nonrefs	_jc_gnu_java_security_provider_GnuDSAPrivateKey$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$refs	_jc_gnu_java_security_provider_GnuDSAPrivateKey$refs;
typedef struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$nonrefs	_jc_gnu_java_security_provider_GnuDSAPrivateKey$nonrefs;
typedef struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object	_jc_gnu_java_security_provider_GnuDSAPrivateKey$object;

typedef const struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$vmethods	_jc_gnu_java_security_provider_GnuDSAPrivateKey$vmethods;
typedef const struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$vtable	_jc_gnu_java_security_provider_GnuDSAPrivateKey$vtable;
typedef const struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$vtype	_jc_gnu_java_security_provider_GnuDSAPrivateKey$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_GnuDSAPrivateKey$method$_init$af886985c1050c26(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuDSAPrivateKey$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *);
extern _jc_byte_array *_jc_gnu_java_security_provider_GnuDSAPrivateKey$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuDSAPrivateKey$method$getFormat$10e2c7b1e3bfcc3b(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *);
extern struct _jc_object *_jc_gnu_java_security_provider_GnuDSAPrivateKey$method$getParams$cf8a9747be586d14(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *);
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_provider_GnuDSAPrivateKey$method$getX$568a3b7b0d38db21(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuDSAPrivateKey$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPrivateKey$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPrivateKey$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPrivateKey$method_info$getFormat$10e2c7b1e3bfcc3b;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPrivateKey$method_info$getParams$cf8a9747be586d14;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPrivateKey$method_info$getX$568a3b7b0d38db21;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPrivateKey$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$vmethods {
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *);
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *);
	struct _jc_java_lang_String$object	*(*getFormat$10e2c7b1e3bfcc3b)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *);
	struct _jc_object	*(*getParams$cf8a9747be586d14)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *);
	struct _jc_java_math_BigInteger$object	*(*getX$568a3b7b0d38db21)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *);
};

// Vtable
struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_provider_GnuDSAPrivateKey$vmethods	gnu_java_security_provider_GnuDSAPrivateKey;
};

// Vtype
struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_GnuDSAPrivateKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$sub_refs {
	_jc_byte_array	*encodedKey;
	struct _jc_java_math_BigInteger$object	*x;
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*q;
	struct _jc_java_math_BigInteger$object	*g;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$refs {
    _jc_gnu_java_security_provider_GnuDSAPrivateKey$sub_refs	gnu_java_security_provider_GnuDSAPrivateKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_provider_GnuDSAPrivateKey$sub_nonrefs	gnu_java_security_provider_GnuDSAPrivateKey;
};

// Object instance structure
struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object {
	_jc_gnu_java_security_provider_GnuDSAPrivateKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_GnuDSAPrivateKey$vtype	*vtype;
	_jc_gnu_java_security_provider_GnuDSAPrivateKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_GnuDSAPrivateKey$vtype _jc_gnu_java_security_provider_GnuDSAPrivateKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_GnuDSAPrivateKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_GnuDSAPrivateKey$class_object;

#endif	/* _JC_gnu_java_security_provider_GnuDSAPrivateKey_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/provider/GnuDSAPrivateKey.h <==
// public class gnu.java.security.provider.GnuDSAPrivateKey

// class file dependencies
// @dep_class 18d6bda3b179d358 gnu_java_security_provider_GnuDSAPrivateKey
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_provider_GnuDSAPrivateKey_H_
#define _JC_gnu_java_security_provider_GnuDSAPrivateKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;
struct _jc_java_security_interfaces_DSAParams$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$sub_refs	_jc_gnu_java_security_provider_GnuDSAPrivateKey$sub_refs;
typedef struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$sub_nonrefs	_jc_gnu_java_security_provider_GnuDSAPrivateKey$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$refs	_jc_gnu_java_security_provider_GnuDSAPrivateKey$refs;
typedef struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$nonrefs	_jc_gnu_java_security_provider_GnuDSAPrivateKey$nonrefs;
typedef struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object	_jc_gnu_java_security_provider_GnuDSAPrivateKey$object;

typedef const struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$vmethods	_jc_gnu_java_security_provider_GnuDSAPrivateKey$vmethods;
typedef const struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$vtable	_jc_gnu_java_security_provider_GnuDSAPrivateKey$vtable;
typedef const struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$vtype	_jc_gnu_java_security_provider_GnuDSAPrivateKey$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_GnuDSAPrivateKey$method$_init$af886985c1050c26(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuDSAPrivateKey$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_gnu_java_security_provider_GnuDSAPrivateKey$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuDSAPrivateKey$method$getFormat$10e2c7b1e3bfcc3b(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_security_provider_GnuDSAPrivateKey$method$getParams$cf8a9747be586d14(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_provider_GnuDSAPrivateKey$method$getX$568a3b7b0d38db21(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuDSAPrivateKey$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPrivateKey$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPrivateKey$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPrivateKey$method_info$getFormat$10e2c7b1e3bfcc3b;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPrivateKey$method_info$getParams$cf8a9747be586d14;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPrivateKey$method_info$getX$568a3b7b0d38db21;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPrivateKey$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$vmethods {
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getFormat$10e2c7b1e3bfcc3b)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getParams$cf8a9747be586d14)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getX$568a3b7b0d38db21)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_provider_GnuDSAPrivateKey$vmethods	gnu_java_security_provider_GnuDSAPrivateKey;
};

// Vtype
struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_GnuDSAPrivateKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$sub_refs {
	_jc_byte_array	*encodedKey;
	struct _jc_java_math_BigInteger$object	*x;
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*q;
	struct _jc_java_math_BigInteger$object	*g;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$refs {
    _jc_gnu_java_security_provider_GnuDSAPrivateKey$sub_refs	gnu_java_security_provider_GnuDSAPrivateKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_provider_GnuDSAPrivateKey$sub_nonrefs	gnu_java_security_provider_GnuDSAPrivateKey;
};

// Object instance structure
struct _jc_gnu_java_security_provider_GnuDSAPrivateKey$object {
	_jc_gnu_java_security_provider_GnuDSAPrivateKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_GnuDSAPrivateKey$vtype	*vtype;
	_jc_gnu_java_security_provider_GnuDSAPrivateKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_GnuDSAPrivateKey$vtype _jc_gnu_java_security_provider_GnuDSAPrivateKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_GnuDSAPrivateKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_GnuDSAPrivateKey$class_object;

#endif	/* _JC_gnu_java_security_provider_GnuDSAPrivateKey_H_ */
